@@ -3,7 +3,7 @@ from cms.models import CMSPlugin
 from django.template.defaultfilters import slugify
 
 class FAQList(models.Model):
-    title = models.CharField(max_length=128)
+    title = models.TextField()
 
     def __unicode__(self):
         return u"%s" % self.title
@@ -13,7 +13,7 @@ class FAQList(models.Model):
 
 class FAQEntry(models.Model):
     faq_list = models.ForeignKey(FAQList, related_name="faq_entries")
-    question = models.CharField(max_length=128)
+    question = models.TextField()
     answer = models.TextField()
 
     def __unicode__(self):
